@@ -3,6 +3,7 @@ from typing import Dict
 from typing import NamedTuple
 
 from all_repos import bitbucket_api
+from all_repos.util import hide_api_key_repr
 
 
 class Settings(NamedTuple):
@@ -14,6 +15,10 @@ class Settings(NamedTuple):
         value = f'{self.username}:{self.app_password}'
         return base64.b64encode(value.encode()).decode()
 
+    # TODO: https://github.com/python/mypy/issues/8543
+    def __repr__(self) -> str:
+        return hide_api_key_repr(self, key='app_password')
+
 
 def list_repos(settings: Settings) -> Dict[str, str]:
     repos = bitbucket_api.get_all(
