@@ -2,6 +2,7 @@ from typing import Dict
 from typing import NamedTuple
 
 from all_repos import github_api
+from all_repos.util import hide_api_key_repr
 
 
 class Settings(NamedTuple):
@@ -13,6 +14,10 @@ class Settings(NamedTuple):
     archived: bool = False
     base_url: str = 'https://api.github.com'
 
+    # TODO: https://github.com/python/mypy/issues/8543
+    def __repr__(self) -> str:
+        return hide_api_key_repr(self)
+
 
 def list_repos(settings: Settings) -> Dict[str, str]:
     repos = github_api.get_all(
